# Orchest CLI

[Website](https://www.orchest.io) —
[Docs](https://docs.orchest.io/en/stable/)

---

Convenience wrapper (around `kubectl` commands) to manage
[Orchest](https://github.com/orchest/orchest) on your Kubernetes cluster. In addition, application
level management, e.g. adding users, can also be done through this package.

## Installation

```sh
pip install orchest-cli
```
